# RocketFlightSim

RocketFlightSim (RFS) is a light-weight flight simulator for experimental rockets. It currently supports simulation of single-stage rockets in the troposphere, from takeoff to apogee. Simple airbrakes can added to the rocket to induce drag. 